==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ia.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "On non pote inviar message de e-posta a le usatores sequente: %s",
    "Turned on maintenance mode" : "Activate modo de mantenentia",
    "Turned off maintenance mode" : "De-activar modo de mantenentia",
    "Updated database" : "Base de datos actualisate",
    "Checked database schema update" : "Il ha verificate actualisation de schema de base de datos",
    "Checked database schema update for apps" : "Il ha verificate actualisation de schema de base de datos pro apps",
    "Updated \"%s\" to %s" : "Actualisava \"%s\" a %s",
    "No image or file provided" : "Il forniva necun imagine o file",
    "Unknown filetype" : "Typo de file incognite",
    "Invalid image" : "Imagine invalide",
    "No temporary profile picture available, try again" : "Necun photo de profilo temporanee disponibile, essaya novemente",
    "%s password reset" : "%s contrasigno re-fixate",
    "Couldn't send reset email. Please contact your administrator." : "On non pote inviar message de configurar ex novo. Pro favor continge tu administrator.",
    "Sunday" : "Dominica",
    "Monday" : "Lunedi",
    "Tuesday" : "Martedi",
    "Wednesday" : "Mercuridi",
    "Thursday" : "Jovedi",
    "Friday" : "Venerdi",
    "Saturday" : "Sabbato",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Jov.",
    "Fri." : "Ven.",
    "Sat." : "Sab.",
    "January" : "januario",
    "February" : "Februario",
    "March" : "Martio",
    "April" : "April",
    "May" : "Mai",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Augusto",
    "September" : "Septembre",
    "October" : "Octobre",
    "November" : "Novembre",
    "December" : "Decembre",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Configurationes",
    "Saving..." : "Salveguardante...",
    "seconds ago" : "secundas passate",
    "I know what I'm doing" : "Io sape lo que io es facente",
    "Password can not be changed. Please contact your administrator." : "Contrasigno non pote esser modificate. Pro favor continge tu administrator.",
    "No" : "No",
    "Yes" : "Si",
    "Choose" : "Seliger",
    "Ok" : "Ok",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de file","{count} conflictos de file"],
    "One file conflict" : "Un conflicto de file",
    "New Files" : "Nove files",
    "Already existing files" : "Files jam existente",
    "Which files do you want to keep?" : "Qual files tu vole mantener?",
    "Cancel" : "Cancellar",
    "Continue" : "Continuar",
    "Error loading file exists template" : "Error quando on incargava patrono de file existente",
    "Very weak password" : "Contrasigno multo debile",
    "Weak password" : "Contrasigno debile",
    "So-so password" : "Contrasigno passabile",
    "Good password" : "Contrasigno bon",
    "Strong password" : "Contrasigno forte",
    "Error occurred while checking server setup" : "Un error occurreva quando on verificava le configuration de le servitor.",
    "Shared" : "Compartite",
    "Shared with {recipients}" : "Compatite con {recipients}",
    "Error" : "Error",
    "Error while sharing" : "Error quando on compartiva",
    "Error while unsharing" : "Error quando on levava le compartir",
    "Error setting expiration date" : "Error quando on fixava le data de expiration",
    "Set expiration date" : "Fixa data de expiration",
    "Expiration date" : "Data de expiration",
    "Choose a password for the public link" : "Selige un contrasigno pro le ligamine public",
    "Sending ..." : "Inviante ...",
    "Email sent" : "Message de e-posta inviate",
    "Resharing is not allowed" : "Il non es permittite compartir plus que un vice",
    "Share link" : "Compartir ligamine",
    "Password protect" : "Protegite per contrasigno",
    "Password" : "Contrasigno",
    "Email link to person" : "Ligamine de e-posta a persona",
    "Send" : "Invia",
    "Shared with you and the group {group} by {owner}" : "Compartite con te e le gruppo {group} per {owner}",
    "Shared with you by {owner}" : "Compartite con te per {owner} ",
    "group" : "gruppo",
    "notify by email" : "notificar per message de e-posta",
    "Unshare" : "Leva compartir",
    "can share" : "pote compartir",
    "can edit" : "pote modificar",
    "create" : "crear",
    "delete" : "deler",
    "access control" : "controlo de accesso",
    "Share" : "Compartir",
    "Warning" : "Aviso",
    "Delete" : "Deler",
    "The object type is not specified." : "Le typo de objecto non es specificate",
    "Enter new" : "Inserta nove",
    "Add" : "Adder",
    "Edit tags" : "Modifica etiquettas",
    "Please reload the page." : "Pro favor recarga le pagina.",
    "The update was successful. Redirecting you to ownCloud now." : "Le actualisation terminava con successo. On redirige nunc a tu ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usatores",
    "Apps" : "Applicationes",
    "Admin" : "Administration",
    "Help" : "Adjuta",
    "Error loading tags" : "Error quando on cargava etiquettas",
    "Tag already exists" : "Etiquetta ja existe",
    "Access forbidden" : "Accesso prohibite",
    "File not found" : "File non trovate",
    "The specified document has not been found on the server." : "Le documento specificate non ha essite trovate sur le servitor.",
    "The share will expire on %s." : "Le compartir expirara le %s.",
    "Cheers!" : "Acclamationes!",
    "Technical details" : "Detalios technic",
    "Remote Address: %s" : "Adresse remote: %s",
    "Request ID: %s" : "ID de requesta: %s",
    "Code: %s" : "Codice: %s",
    "Message: %s" : "Message: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Rango: %s",
    "Trace" : "Tracia",
    "Create an <strong>admin account</strong>" : "Crear un <strong>conto de administration</strong>",
    "Username" : "Nomine de usator",
    "Storage & database" : "Immagazinage & base de datos",
    "Data folder" : "Dossier de datos",
    "Configure the database" : "Configurar le base de datos",
    "Only %s is available." : "Solmente %s es disponibile",
    "Database user" : "Usator de base de datos",
    "Database password" : "Contrasigno de base de datos",
    "Database name" : "Nomine de base de datos",
    "Database tablespace" : "Spatio de tabella de base de datos",
    "Database host" : "Hospite de base de datos",
    "Finish setup" : "Terminar configuration",
    "Finishing …" : "Terminante ...",
    "Log out" : "Clauder le session",
    "Search" : "Cercar",
    "Server side authentication failed!" : "Il falleva authentication de latere servitor!",
    "Please contact your administrator." : "Pro favor continge tu administrator.",
    "Log in" : "Aperir session",
    "Alternative Logins" : "Accessos de autorisation alternative",
    "Use the following link to reset your password: {link}" : "Usa le ligamine sequente pro re-fixar tu contrasigno: {link}",
    "New password" : "Nove contrasigno",
    "New Password" : "Nove contrasigno",
    "Reset password" : "Reinitialisar contrasigno",
    "Thank you for your patience." : "Gratias pro tu patientia.",
    "Start update" : "Initia actualisation",
    "Password can not be changed. Please contact your administrator." : "Contrasigno non pote esser modificate. Pro favor continge tu administrator."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/ia.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "Il forniva necun imagine o file",
    "Unknown filetype" : "Typo de file incognite",
    "Invalid image" : "Imagine invalide",
    "No temporary profile picture available, try again" : "Necun photo de profilo temporanee disponibile, essaya novemente",
    "%s password reset" : "%s contrasigno re-fixate",
    "Couldn't send reset email. Please contact your administrator." : "On non pote inviar message de configurar ex novo. Pro favor continge tu administrator.",
    "Error loading tags" : "Error quando on cargava etiquettas",
    "Tag already exists" : "Etiquetta ja existe",
    "Couldn't send mail to following users: %s " : "On non pote inviar message de e-posta a le usatores sequente: %s",
    "Turned on maintenance mode" : "Activate modo de mantenentia",
    "Turned off maintenance mode" : "De-activar modo de mantenentia",
    "Updated database" : "Base de datos actualisate",
    "Checked database schema update" : "Il ha verificate actualisation de schema de base de datos",
    "Checked database schema update for apps" : "Il ha verificate actualisation de schema de base de datos pro apps",
    "Updated \"%s\" to %s" : "Actualisava \"%s\" a %s",
    "Sunday" : "Dominica",
    "Monday" : "Lunedi",
    "Tuesday" : "Martedi",
    "Wednesday" : "Mercuridi",
    "Thursday" : "Jovedi",
    "Friday" : "Venerdi",
    "Saturday" : "Sabbato",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mer.",
    "Thu." : "Jov.",
    "Fri." : "Ven.",
    "Sat." : "Sab.",
    "January" : "januario",
    "February" : "Februario",
    "March" : "Martio",
    "April" : "April",
    "May" : "Mai",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Augusto",
    "September" : "Septembre",
    "October" : "Octobre",
    "November" : "Novembre",
    "December" : "Decembre",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Configurationes",
    "Saving..." : "Salveguardante...",
    "seconds ago" : "secundas passate",
    "I know what I'm doing" : "Io sape lo que io es facente",
    "Password can not be changed. Please contact your administrator." : "Contrasigno non pote esser modificate. Pro favor continge tu administrator.",
    "No" : "No",
    "Yes" : "Si",
    "Choose" : "Seliger",
    "Ok" : "Ok",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de file","{count} conflictos de file"],
    "One file conflict" : "Un conflicto de file",
    "New Files" : "Nove files",
    "Already existing files" : "Files jam existente",
    "Which files do you want to keep?" : "Qual files tu vole mantener?",
    "Cancel" : "Cancellar",
    "Continue" : "Continuar",
    "Error loading file exists template" : "Error quando on incargava patrono de file existente",
    "Very weak password" : "Contrasigno multo debile",
    "Weak password" : "Contrasigno debile",
    "So-so password" : "Contrasigno passabile",
    "Good password" : "Contrasigno bon",
    "Strong password" : "Contrasigno forte",
    "Error occurred while checking server setup" : "Un error occurreva quando on verificava le configuration de le servitor.",
    "Shared" : "Compartite",
    "Shared with {recipients}" : "Compatite con {recipients}",
    "Error" : "Error",
    "Error while sharing" : "Error quando on compartiva",
    "Error while unsharing" : "Error quando on levava le compartir",
    "Error setting expiration date" : "Error quando on fixava le data de expiration",
    "Set expiration date" : "Fixa data de expiration",
    "Expiration date" : "Data de expiration",
    "Choose a password for the public link" : "Selige un contrasigno pro le ligamine public",
    "Resharing is not allowed" : "Il non es permittite compartir plus que un vice",
    "Share link" : "Compartir ligamine",
    "Password protect" : "Protegite per contrasigno",
    "Password" : "Contrasigno",
    "Email link to person" : "Ligamine de e-posta a persona",
    "Send" : "Invia",
    "Sending ..." : "Inviante ...",
    "Email sent" : "Message de e-posta inviate",
    "Shared with you and the group {group} by {owner}" : "Compartite con te e le gruppo {group} per {owner}",
    "Shared with you by {owner}" : "Compartite con te per {owner} ",
    "group" : "gruppo",
    "notify by email" : "notificar per message de e-posta",
    "Unshare" : "Leva compartir",
    "can share" : "pote compartir",
    "can edit" : "pote modificar",
    "create" : "crear",
    "delete" : "deler",
    "access control" : "controlo de accesso",
    "Share" : "Compartir",
    "Warning" : "Aviso",
    "Delete" : "Deler",
    "The object type is not specified." : "Le typo de objecto non es specificate",
    "Enter new" : "Inserta nove",
    "Add" : "Adder",
    "Edit tags" : "Modifica etiquettas",
    "Please reload the page." : "Pro favor recarga le pagina.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Le actualisation terminava sin successo. Pro favor tu reporta iste problema al  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Le actualisation terminava con successo. On redirige nunc a tu ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usatores",
    "Apps" : "Applicationes",
    "Admin" : "Administration",
    "Help" : "Adjuta",
    "Access forbidden" : "Accesso prohibite",
    "File not found" : "File non trovate",
    "The specified document has not been found on the server." : "Le documento specificate non ha essite trovate sur le servitor.",
    "The share will expire on %s." : "Le compartir expirara le %s.",
    "Cheers!" : "Acclamationes!",
    "Technical details" : "Detalios technic",
    "Remote Address: %s" : "Adresse remote: %s",
    "Request ID: %s" : "ID de requesta: %s",
    "Code: %s" : "Codice: %s",
    "Message: %s" : "Message: %s",
    "File: %s" : "File: %s",
    "Line: %s" : "Rango: %s",
    "Trace" : "Tracia",
    "Create an <strong>admin account</strong>" : "Crear un <strong>conto de administration</strong>",
    "Username" : "Nomine de usator",
    "Storage & database" : "Immagazinage & base de datos",
    "Data folder" : "Dossier de datos",
    "Configure the database" : "Configurar le base de datos",
    "Only %s is available." : "Solmente %s es disponibile",
    "Database user" : "Usator de base de datos",
    "Database password" : "Contrasigno de base de datos",
    "Database name" : "Nomine de base de datos",
    "Database tablespace" : "Spatio de tabella de base de datos",
    "Database host" : "Hospite de base de datos",
    "Finish setup" : "Terminar configuration",
    "Finishing …" : "Terminante ...",
    "Log out" : "Clauder le session",
    "Search" : "Cercar",
    "Server side authentication failed!" : "Il falleva authentication de latere servitor!",
    "Please contact your administrator." : "Pro favor continge tu administrator.",
    "Log in" : "Aperir session",
    "Alternative Logins" : "Accessos de autorisation alternative",
    "Use the following link to reset your password: {link}" : "Usa le ligamine sequente pro re-fixar tu contrasigno: {link}",
    "New password" : "Nove contrasigno",
    "New Password" : "Nove contrasigno",
    "Reset password" : "Reinitialisar contrasigno",
    "Thank you for your patience." : "Gratias pro tu patientia.",
    "Start update" : "Initia actualisation"
},
"nplurals=2; plural=(n != 1);");
